@@ -1,4 +1,5 @@
-// Copyright (c) 2020 Red Hat, Inc.
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package patching
 
@@ -14,9 +15,9 @@ import (
 	"sigs.k8s.io/kustomize/v3/pkg/resource"
 	"sigs.k8s.io/yaml"
 
-	mcov1beta1 "github.com/stolostron/multicluster-monitoring-operator/pkg/apis/observability/v1beta1"
-	mcoconfig "github.com/stolostron/multicluster-monitoring-operator/pkg/config"
-	"github.com/stolostron/multicluster-monitoring-operator/pkg/util"
+	mcov1beta2 "github.com/open-cluster-management/multicluster-observability-operator/api/v1beta2"
+	mcoconfig "github.com/open-cluster-management/multicluster-observability-operator/pkg/config"
+	"github.com/open-cluster-management/multicluster-observability-operator/pkg/util"
 )
 
 const (
@@ -25,9 +26,9 @@ const (
 
 type patchGenerateFn func(
 	res *resource.Resource,
-	mco *mcov1beta1.MultiClusterObservability) (ifc.Kunstructured, error)
+	mco *mcov1beta2.MultiClusterObservability) (ifc.Kunstructured, error)
 
-func ApplyGlobalPatches(res *resource.Resource, mco *mcov1beta1.MultiClusterObservability) error {
+func ApplyGlobalPatches(res *resource.Resource, mco *mcov1beta2.MultiClusterObservability) error {
 
 	// for _, generate := range []patchGenerateFn{
 	// 	//generateImagePatch,
@@ -50,7 +51,7 @@ func ApplyGlobalPatches(res *resource.Resource, mco *mcov1beta1.MultiClusterObse
 
 func generateImagePatch(
 	res *resource.Resource,
-	mco *mcov1beta1.MultiClusterObservability) (ifc.Kunstructured, error) {
+	mco *mcov1beta2.MultiClusterObservability) (ifc.Kunstructured, error) {
 	imageFromTemplate, err := res.GetString(specFirstContainer + ".image") // need to loop through all images
 	if err != nil {
 		return nil, err
@@ -65,7 +66,7 @@ func generateImagePatch(
 	container, _ := res.GetFieldValue(specFirstContainer)
 	containerMap, _ := container.(map[string]interface{})
 	containerMap["image"] = generatedImage
-	containerMap["imagePullPolicy"] = mco.Spec.ImagePullPolicy
+	containerMap["imagePullPolicy"] = mcoconfig.GetImagePullPolicy(mco.Spec)
 
 	return newKunstructuredForSpecContainers(containerMap), nil
 }
@@ -82,12 +83,10 @@ spec:
 
 func generateImagePullSecretsPatch(
 	res *resource.Resource,
-	mco *mcov1beta1.MultiClusterObservability) (ifc.Kunstructured, error) {
+	mco *mcov1beta2.MultiClusterObservability) (ifc.Kunstructured, error) {
+
+	pullSecret := mcoconfig.GetImagePullSecret(mco.Spec)
 
-	pullSecret := mco.Spec.ImagePullSecret
-	if pullSecret == "" {
-		return nil, nil
-	}
 	template := strings.Replace(imagePullSecretsTemplate, "__kind__", res.GetKind(), 1)
 	template = strings.Replace(template, "__pullsecrets__", pullSecret, 1)
 	json, err := yaml.YAMLToJSON([]byte(template))
@@ -109,7 +108,7 @@ func generateImagePullSecretsPatch(
 
 // func generateNodeSelectorPatch(
 // 	res *resource.Resource,
-// 	mco *mcov1beta1.MultiClusterObservability) (ifc.Kunstructured, error) {
+// 	mco *mcov1beta2.MultiClusterObservability) (ifc.Kunstructured, error) {
 
 // 	nodeSelectorOptions := mco.Spec.NodeSelector
 // 	if nodeSelectorOptions == nil {
